package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERBoolean;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import java.math.BigInteger;

public class BasicConstraints extends ASN1Encodable {
   DERBoolean cA;
   DERInteger pathLenConstraint;

   public static BasicConstraints getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static BasicConstraints getInstance(Object obj) {
      if (obj != null && !(obj instanceof BasicConstraints)) {
         if (obj instanceof ASN1Sequence) {
            return new BasicConstraints((ASN1Sequence)obj);
         } else if (obj instanceof X509Extension) {
            return getInstance(X509Extension.convertValueToObject((X509Extension)obj));
         } else {
            throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
         }
      } else {
         return (BasicConstraints)obj;
      }
   }

   public BasicConstraints(ASN1Sequence seq) {
      this.cA = new DERBoolean(false);
      this.pathLenConstraint = null;
      if (seq.size() == 0) {
         this.cA = null;
         this.pathLenConstraint = null;
      } else {
         if (seq.getObjectAt(0) instanceof DERBoolean) {
            this.cA = DERBoolean.getInstance(seq.getObjectAt(0));
         } else {
            this.cA = null;
            this.pathLenConstraint = DERInteger.getInstance(seq.getObjectAt(0));
         }

         if (seq.size() > 1) {
            if (this.cA == null) {
               throw new IllegalArgumentException("wrong sequence in constructor");
            }

            this.pathLenConstraint = DERInteger.getInstance(seq.getObjectAt(1));
         }
      }

   }

   /** @deprecated */
   public BasicConstraints(boolean cA, int pathLenConstraint) {
      DERBoolean var3;
      var3 = new DERBoolean.<init>(false);
      this.cA = var3;
      this.pathLenConstraint = null;
      if (cA) {
         BasicConstraints var10000 = this;
         BasicConstraints var10001 = this;
         DERBoolean var4;
         var4 = new DERBoolean.<init>(cA);
         var10001.cA = var4;
         DERInteger var5;
         var5 = new DERInteger.<init>(pathLenConstraint);
         var10000.pathLenConstraint = var5;
      } else {
         this.cA = null;
         this.pathLenConstraint = null;
      }

   }

   public BasicConstraints(boolean cA) {
      boolean var10000 = cA;
      super();
      DERBoolean cA1;
      cA1 = new DERBoolean.<init>(false);
      this.cA = cA1;
      this.pathLenConstraint = null;
      if (var10000) {
         cA1 = new DERBoolean.<init>(true);
         this.cA = cA1;
      } else {
         this.cA = null;
      }

      this.pathLenConstraint = null;
   }

   public BasicConstraints(int pathLenConstraint) {
      BasicConstraints var10000 = this;
      BasicConstraints var10001 = this;
      BasicConstraints var10002 = this;
      BasicConstraints var10003 = this;
      super();
      DERBoolean var2;
      var2 = new DERBoolean.<init>(false);
      var10003.cA = var2;
      var10002.pathLenConstraint = null;
      var2 = new DERBoolean.<init>(true);
      var10001.cA = var2;
      DERInteger var3;
      var3 = new DERInteger.<init>(pathLenConstraint);
      var10000.pathLenConstraint = var3;
   }

   public boolean isCA() {
      DERBoolean var1;
      return (var1 = this.cA) != null && var1.isTrue();
   }

   public BigInteger getPathLenConstraint() {
      DERInteger var1;
      return (var1 = this.pathLenConstraint) != null ? var1.getValue() : null;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      DERBoolean var2;
      if ((var2 = this.cA) != null) {
         var1.add(var2);
      }

      DERInteger var3;
      if ((var3 = this.pathLenConstraint) != null) {
         var1.add(var3);
      }

      return new DERSequence(var1);
   }

   public String toString() {
      if (this.pathLenConstraint == null) {
         return this.cA == null ? "BasicConstraints: isCa(false)" : "BasicConstraints: isCa(" + this.isCA() + ")";
      } else {
         return "BasicConstraints: isCa(" + this.isCA() + "), pathLenConstraint = " + this.pathLenConstraint.getValue();
      }
   }
}
